@@ -14,6 +14,7 @@
 # Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
 # Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -40,7 +41,7 @@ from github.GithubObject import Attribute, CompletableGithubObject, NotSet
 
 class AuthorizationApplication(CompletableGithubObject):
     """
-    This class represents AuthorizationApplications
+    This class represents AuthorizationApplications.
     """
 
     def _initAttributes(self) -> None:
