@@ -62,7 +62,11 @@
 # Copyright 2023 Roberto Pastor Muela <37798125+RobPasMue@users.noreply.github.com>#
 # Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
 # Copyright 2023 Wojciech Barczyński <104033489+WojciechBarczynski@users.noreply.github.com>#
+# Copyright 2024 Benjamin K <53038537+treee111@users.noreply.github.com>       #
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2024 Heitor Polidoro <heitor.polidoro@gmail.com>                   #
+# Copyright 2024 Thomas Crowley <15927917+thomascrowley@users.noreply.github.com>#
+# Copyright 2024 jodelasur <34933233+jodelasur@users.noreply.github.com>       #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -406,6 +410,12 @@ class Repository(Framework.TestCase):
         self.assertEqual(release.draft, False)
         self.assertEqual(release.prerelease, False)
 
+    def testCreateGitReleaseGenerateReleaseNotes(self):
+        release = self.repo.create_git_release("vX.Y.Z-by-PyGithub-acctest-release-notes", generate_release_notes=True)
+        self.assertEqual(release.tag_name, "vX.Y.Z-by-PyGithub-acctest-release-notes")
+        self.assertEqual(release.draft, False)
+        self.assertEqual(release.prerelease, False)
+
     def testCreateGitReleaseWithAllArguments(self):
         release = self.repo.create_git_release(
             "vX.Y.Z-by-PyGithub-acctest2",
@@ -481,13 +491,6 @@ class Repository(Framework.TestCase):
         without_payload = self.repo.create_repository_dispatch("type")
         self.assertTrue(without_payload)
 
-    @mock.patch("github.PublicKey.encrypt")
-    def testCreateSecret(self, encrypt):
-        # encrypt returns a non-deterministic value, we need to mock it so the replay data matches
-        encrypt.return_value = "M+5Fm/BqTfB90h3nC7F3BoZuu3nXs+/KtpXwxm9gG211tbRo0F5UiN0OIfYT83CKcx9oKES9Va4E96/b"
-        secret = self.repo.create_secret("secret-name", "secret-value")
-        self.assertIsNotNone(secret)
-
     @mock.patch("github.PublicKey.encrypt")
     def testRepoSecrets(self, encrypt):
         # encrypt returns a non-deterministic value, we need to mock it so the replay data matches
@@ -633,6 +636,10 @@ class Repository(Framework.TestCase):
     def testCollaboratorPermission(self):
         self.assertEqual(self.repo.get_collaborator_permission("jacquev6"), "admin")
 
+    def testAddToCollaboratorsCustomRole(self):
+        lyloa = self.g.get_user("Lyloa")
+        self.repo.add_to_collaborators(lyloa, "custom_role")
+
     def testGetPendingInvitations(self):
         lyloa = self.g.get_user("Lyloa")
         self.repo.add_to_collaborators(lyloa)
@@ -1225,6 +1232,13 @@ class Repository(Framework.TestCase):
             [110932306, 110932159, 110932072, 110286191, 110278769],
         )
 
+    def testGetWorkflowRunsCreated(self):
+        self.assertListKeyEqual(
+            self.g.get_repo("PyGithub/PyGithub").get_workflow_runs(created="2022-12-24"),
+            lambda r: r.id,
+            [3770390952],
+        )
+
     def testGetSourceImport(self):
         import_repo = self.g.get_user("brix4dayz").get_repo("source-import-test")
         source_import = import_repo.get_source_import()
@@ -1961,6 +1975,28 @@ class Repository(Framework.TestCase):
         for matched_repo_variable in matched_repo_variables:
             matched_repo_variable.delete()
 
+    @mock.patch("github.PublicKey.encrypt")
+    def testCreateRepoActionsSecret(self, encrypt):
+        repo = self.g.get_repo("demoorg/demo-repo-1")
+        # encrypt returns a non-deterministic value, we need to mock it so the replay data matches
+        encrypt.return_value = "M+5Fm/BqTfB90h3nC7F3BoZuu3nXs+/KtpXwxm9gG211tbRo0F5UiN0OIfYT83CKcx9oKES9Va4E96/b"
+        secret = repo.create_secret("secret_name", "secret-value", "actions")
+        self.assertIsNotNone(secret)
+
+    @mock.patch("github.PublicKey.encrypt")
+    def testCreateRepoDependabotSecret(self, encrypt):
+        repo = self.g.get_repo("demoorg/demo-repo-1")
+        # encrypt returns a non-deterministic value, we need to mock it so the replay data matches
+        encrypt.return_value = "M+5Fm/BqTfB90h3nC7F3BoZuu3nXs+/KtpXwxm9gG211tbRo0F5UiN0OIfYT83CKcx9oKES9Va4E96/b"
+        secret = repo.create_secret("secret_name", "secret-value", "dependabot")
+        self.assertIsNotNone(secret)
+
+    def testRepoGetSecretAssertion(self):
+        repo = self.g.get_repo("demoorg/demo-repo-1")
+        with self.assertRaises(AssertionError) as exc:
+            repo.get_secret(secret_name="splat", secret_type="supersecret")
+        self.assertEqual(str(exc.exception), "secret_type should be actions or dependabot")
+
 
 class LazyRepository(Framework.TestCase):
     def setUp(self):
